pub struct ParseError<'a> { /* private fields */ }Expand description
Error type for the parsing lifecycle.
Wraps one or more diagnostics together with the SourceMap.
Implementations
Sourceimpl<'a> ParseError<'a>
impl<'a> ParseError<'a>
Sourcepub fn new(diagnostics: Vec<Diagnostic>, source_map: SourceMap<'a>) -> Self
pub fn new(diagnostics: Vec<Diagnostic>, source_map: SourceMap<'a>) -> Self
Create a new parse error from diagnostics and a source map.
Sourcepub fn from_diagnostic(
diagnostic: Diagnostic,
source_map: SourceMap<'a>,
) -> Self
pub fn from_diagnostic( diagnostic: Diagnostic, source_map: SourceMap<'a>, ) -> Self
Create a parse error from a single diagnostic and a source map.
Sourcepub fn source_map(&self) -> &SourceMap<'a>
pub fn source_map(&self) -> &SourceMap<'a>
Get the source map associated with this error.
Sourcepub fn diagnostics(&self) -> &[Diagnostic]
pub fn diagnostics(&self) -> &[Diagnostic]
Get all diagnostics in this error.