pub struct Span { /* private fields */ }Expand description
A byte range representing a location in source text.
Spans track the start and end byte offsets of syntax elements, enabling precise source mapping for diagnostics, suggestions, and tooling.
Examples
// Create a span covering bytes 10-25
let span = Span::new(10..25);
assert_eq!(span.start(), 10);
assert_eq!(span.end(), 25);
assert_eq!(span.len(), 15);
// Combine two spans into one that covers both
let other = Span::new(30..40);
let combined = span.union(other);
assert_eq!(combined.start(), 10);
assert_eq!(combined.end(), 40);Implementations